==> prov-jsonld-0.9.21-sources.jar: org/openprovenance/prov/core/jsonld11/serialization/Constants.java <==
package org.openprovenance.prov.core.jsonld11.serialization;

public interface Constants {
    String PROPERTY_AT_TYPE = "@type";
    String PROPERTY_AT_VALUE = "@value";

    String PROPERTY_STRING_VALUE = "@value";
    String PROPERTY_STRING_LANG = "@language";

    String PROPERTY_BLOCK_TYPE = "@type";

    String PROPERTY_PROV_TYPE = "prov:type";


    String PROPERTY_PROV_ACTIVITY = "prov:Activity";
    String PROPERTY_PROV_AGENT = "prov:Agent";
    String PROPERTY_PROV_ENTITY = "prov:Entity";
    String PROPERTY_PROV_USED = "prov:Usage";
    String PROPERTY_PROV_GENERATION = "prov:Generation";
    String PROPERTY_PROV_ASSOCIATION = "prov:Association";
    String PROPERTY_PROV_ATTRIBUTION = "prov:Attribution";
    String PROPERTY_PROV_SPECIALIZATION = "prov:Specialization";
    String PROPERTY_PROV_ALTERNATE = "prov:Alternate";
    String PROPERTY_PROV_DERIVATION = "prov:Derivation";
    String PROPERTY_PROV_COMMUNICATION = "prov:Communication";
    String PROPERTY_PROV_INFLUENCE = "prov:Influence";
    String PROPERTY_PROV_MEMBERSHIP = "prov:Membership";
    String PROPERTY_PROV_INVALIDATION = "prov:Invalidation";
    String PROPERTY_PROV_START = "prov:Start";
    String PROPERTY_PROV_END = "prov:End";
    String PROPERTY_PROV_DELEGATION = "prov:Delegation";
    String PROPERTY_PROV_BUNDLE = "prov:Bundle";
    String PROPERTY_PROV_QUALIFIED_SPECIALIZATION = "prov:QualifiedSpecialization";
    String PROPERTY_PROV_QUALIFIED_ALTERNATE = "prov:QualifiedAlternate";
    String PROPERTY_PROV_QUALIFIED_MEMBERSHIP = "prov:QualifiedMembership";
}

==> prov-jsonld-2.0.5-sources.jar: org/openprovenance/prov/core/jsonld11/serialization/Constants.java <==
package org.openprovenance.prov.core.jsonld11.serialization;

public interface Constants {
    String PROPERTY_AT_TYPE = "@type";
    String PROPERTY_AT_VALUE = "@value";

    String PROPERTY_STRING_VALUE = "@value";
    String PROPERTY_STRING_LANG = "@language";

    String PROPERTY_BLOCK_TYPE = "@type";

    String PROPERTY_PROV_TYPE = "prov:type";


    String PROPERTY_PROV_ACTIVITY = "prov:Activity";
    String PROPERTY_PROV_AGENT = "prov:Agent";
    String PROPERTY_PROV_ENTITY = "prov:Entity";
    String PROPERTY_PROV_USED = "prov:Usage";
    String PROPERTY_PROV_GENERATION = "prov:Generation";
    String PROPERTY_PROV_ASSOCIATION = "prov:Association";
    String PROPERTY_PROV_ATTRIBUTION = "prov:Attribution";
    String PROPERTY_PROV_SPECIALIZATION = "prov:Specialization";
    String PROPERTY_PROV_ALTERNATE = "prov:Alternate";
    String PROPERTY_PROV_DERIVATION = "prov:Derivation";
    String PROPERTY_PROV_COMMUNICATION = "prov:Communication";
    String PROPERTY_PROV_INFLUENCE = "prov:Influence";
    String PROPERTY_PROV_MEMBERSHIP = "prov:Membership";
    String PROPERTY_PROV_INVALIDATION = "prov:Invalidation";
    String PROPERTY_PROV_START = "prov:Start";
    String PROPERTY_PROV_END = "prov:End";
    String PROPERTY_PROV_DELEGATION = "prov:Delegation";
    String PROPERTY_PROV_BUNDLE = "prov:Bundle";
    String PROPERTY_PROV_QUALIFIED_SPECIALIZATION = "prov:QualifiedSpecialization";
    String PROPERTY_PROV_QUALIFIED_ALTERNATE = "prov:QualifiedAlternate";
    String PROPERTY_PROV_QUALIFIED_MEMBERSHIP = "prov:QualifiedMembership";
    String OLD_JSONLD_CONTEXT_URL = "http://openprovenance.org/prov.jsonld";
    String JSONLD_CONTEXT_URL = "https://openprovenance.org/prov-jsonld/context.json";
}
